@@ -20,8 +20,8 @@ print(f"Python version: {sys.version}")
 print(f"Platform: {sys.platform}")
 
 # Add project root to sys.path to allow importing parallel_llm from source
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
+# sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+# print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
 
 # Try to import dependencies
 PYTORCH_AVAILABLE = False
@@ -96,8 +96,14 @@ def main():
 
         # 2. Prepare Inputs
         # Load Image
-        url = "http://images.cocodataset.org/val2017/000000039769.jpg"
-        image = Image.open(requests.get(url, stream=True).raw)
+        try:
+            url = "http://images.cocodataset.org/val2017/000000039769.jpg"
+            image = Image.open(requests.get(url, stream=True).raw)
+        except Exception as e:
+            print(f"Failed to download image: {e}")
+            print("Using mock image for demo...")
+            # Create a simple mock image (normalized RGB)
+            image = Image.new('RGB', (224, 224), color=(128, 128, 128))
 
         # Process Image
         image_processor = AutoImageProcessor.from_pretrained("google/vit-base-patch16-224")
