@@ -20,8 +20,8 @@ print(f"Python version: {sys.version}")
 print(f"Platform: {sys.platform}")
 
 # Add project root to sys.path to allow importing parallel_llm from source
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
+# sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+# print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
 
 # Try to import dependencies
 PYTORCH_AVAILABLE = False
