@@ -20,8 +20,8 @@ print(f"Python version: {sys.version}")
 print(f"Platform: {sys.platform}")
 
 # Add project root to sys.path to allow importing parallel_llm from source
-sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
-print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
+# sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
+# print(f"Added to path: {os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))}")
 
 # Try to import dependencies
 PYTORCH_AVAILABLE = False
@@ -98,31 +98,33 @@ def main():
             print("="*50)
 
         # 2. Configuration
-        # Model Configuration (very small for demo)
+        # Model Configuration (CUDA compatible)
         model_config = ModelConfig(
-            vocab_size=1000,       # Small vocab for demo (not full GPT-2)
-            hidden_size=128,       # Very small model for demo
-            num_hidden_layers=2,   # Very few layers for demo
-            num_attention_heads=4, # Fewer heads
-            num_diffusion_steps=5, # Very few diffusion steps for demo
-            use_energy_model=False, # Disable for compatibility
-            use_flash_attention=False  # Disable for compatibility
+            vocab_size=50257,      # Full GPT-2 vocabulary
+            hidden_size=512,       # Medium size for CUDA compatibility
+            num_hidden_layers=6,   # Fewer layers for demo
+            num_attention_heads=8, # Standard heads
+            num_diffusion_steps=10, # Fewer diffusion steps for demo
+            use_energy_model=False, # Disable for demo
+            use_flash_attention=False,  # Disable flash attention for compatibility
+            dtype=torch.float32  # Use FP32 for stability
         )
 
         # Training Configuration
         train_config = TrainingConfig(
             output_dir="./checkpoints/unimodal",
-            num_train_steps=50,   # Very small for ultra-quick demo
-            batch_size=2,  # Very small batch size for demo
-            learning_rate=1e-3,  # Higher learning rate for quick demo
-            warmup_steps=5,   # Very short warmup
+            num_train_steps=10,   # Very small for ultra-quick demo
+            batch_size=1,  # Single batch for demo
+            learning_rate=1e-4,  # Standard learning rate
+            warmup_steps=2,   # Very short warmup
             use_fsdp=False,  # Disable FSDP for single-device training
             use_deepspeed=False,  # Disable DeepSpeed for single-device training
-            mixed_precision="no",  # Disable mixed precision for compatibility
-            logging_steps=5,
-            save_steps=50,
-            eval_steps=25,
-            use_wandb=False # Set to True to enable WandB logging
+            mixed_precision="bf16" if torch.cuda.is_available() else "no",  # Use BF16 on CUDA
+            logging_steps=1,
+            save_steps=10,
+            eval_steps=5,
+            use_wandb=False, # Set to True to enable WandB logging
+            use_torch_compile=False  # Disable torch compile for CUDA compatibility
         )
 
         # 3. Data Preparation
