@@ -57,8 +57,11 @@ class DistributedTrainer:
         # Setup mixed precision
         self._setup_mixed_precision()
 
-        # Compile model if requested
-        if train_config.use_torch_compile:
+        # Setup loss function
+        self._setup_loss()
+
+        # Compile model if requested (disabled by default for CUDA compatibility)
+        if getattr(train_config, 'use_torch_compile', False):
             self._compile_model()
 
         # Setup logging
@@ -309,6 +312,15 @@ class DistributedTrainer:
                 milestones=[self.train_config.warmup_steps],
             )
 
+    def _setup_loss(self):
+        """Setup loss function for diffusion training"""
+        from .losses import DiffusionLoss
+        self.loss_fn = DiffusionLoss(
+            vocab_size=self.model_config.vocab_size,
+            use_energy_model=self.model_config.use_energy_model,
+            label_smoothing=0.1  # Small amount of label smoothing
+        )
+
     def _setup_mixed_precision(self):
         """Setup mixed precision training"""
         if self.train_config.use_deepspeed or self.train_config.use_fsdp:
@@ -406,8 +418,52 @@ class DistributedTrainer:
             progress_bar.close()
 
     def training_step(self, batch: Dict[str, torch.Tensor]) -> torch.Tensor:
-        """Single training step - to be implemented by specific model"""
-        raise NotImplementedError("Implement training_step in subclass")
+        """Single training step for diffusion training"""
+        input_ids = batch['input_ids']  # (batch, seq_len)
+        attention_mask = batch.get('attention_mask')  # (batch, seq_len)
+
+        batch_size, seq_len = input_ids.shape
+
+        # Sample random timestep for diffusion
+        # Use a simple linear schedule from 0 to max_steps
+        max_timestep = self.model_config.num_diffusion_steps
+        timestep = torch.randint(0, max_timestep, (batch_size,), device=self.device)
+
+        # Create noisy version by masking random positions
+        # For simplicity, mask a fixed percentage of tokens
+        noise_ratio = 0.15  # 15% masking like BERT
+
+        # Create mask for positions to noise
+        mask_positions = torch.rand(batch_size, seq_len, device=self.device) < noise_ratio
+
+        # Don't mask special tokens (assuming first and last are special)
+        # For simplicity, avoid masking first and last tokens
+        mask_positions[:, 0] = False  # Don't mask BOS
+        mask_positions[:, -1] = False  # Don't mask EOS if present
+
+        # Apply masking - replace with padding token (used as MASK)
+        noisy_input_ids = input_ids.clone()
+        mask_token_id = getattr(self.model, 'padding_idx', 0)  # Use model's padding token
+        noisy_input_ids[mask_positions] = mask_token_id
+
+        # Forward pass
+        logits, confidence = self.model(
+            input_ids=noisy_input_ids,
+            timestep=timestep,
+            attention_mask=attention_mask,
+            return_confidence=True
+        )
+
+        # Compute diffusion loss
+        # The loss compares predictions at masked positions to original tokens
+        loss = self.loss_fn(
+            logits=logits,
+            targets=input_ids,
+            mask_positions=mask_positions,
+            confidence=confidence
+        )
+
+        return loss
 
     def evaluate(self):
         """Evaluation loop"""
